This is a Python wrapper of the
[imagemorph](https://github.com/GrHound/imagemorph.c) tool, a program to apply
random elastic rubbersheet  transforms to images for  augmenting training sets
in machine learning/deep learning. Original Author: Marius Bulacu (.pgm version
for characters). Adapted for .ppm and color: Lambert Schomaker

Using this Python wrapper, any image type can be processed (not just .ppm), as
long as it can be loaded with OpenCV.

Please cite:

M Bulacu, A Brink, T van der Zant, L Schomaker (2009).
Recognition of handwritten numerical fields in a 
large single-writer historical collection,
10th International Conference on Document Analysis and Recognition, 
pp. 808-812, DOI: 10.1109/ICDAR.2009.8 
